# PyPI Image Example

This package does nothing. It is just an example of an image in a README.md file. 

### Test Image

![sparkles](static/sparkles.png)

This is the Twitter 1.0 Emoji "[Sparkles](https://emojipedia.org/twitter/twemoji-1.0/sparkles/)". 
